local LOOT_ITEM = _G.LOOT_ITEM
local LOOT_ITEM_MULTIPLE = _G.LOOT_ITEM_MULTIPLE
local LOOT_ITEM_PUSHED = _G.LOOT_ITEM_PUSHED
local LOOT_ITEM_PUSHED_MULTIPLE = _G.LOOT_ITEM_PUSHED_MULTIPLE
local LOOT_ITEM_PUSHED_SELF = _G.LOOT_ITEM_PUSHED_SELF
local LOOT_ITEM_PUSHED_SELF_MULTIPLE = _G.LOOT_ITEM_PUSHED_SELF_MULTIPLE
local LOOT_ITEM_SELF = _G.LOOT_ITEM_SELF
local LOOT_ITEM_SELF_MULTIPLE = _G.LOOT_ITEM_SELF_MULTIPLE

local Deformat = LibStub("LibDeformat-3.0")


function DraconisErus_TableSearch(tab,el)
	retVal = 0
    for index, value in pairs(tab) do
        if value == el then
            retVal = index
			break
        end
    end
	return retVal
end

function DraconisErus_GenerateID(isRaid)
	local retVal = ""
	for i=1,24 do
		if i == 5 or i == 9 or i == 13 then
			retVal = retVal.."-"
		end
		retVal = retVal..strchar(math.random(26)+64)
	end
	if isRaid then
		retVal = date("%Y%m%d").."-"..retVal
	end
	return retVal
end

function DraconisErus_Debug(message)
	if DERR_DEBUG then
		--while strlen(message) > 25 do
		--	DraconisErusRaidRecorder:Print(string.sub(message,1,25))
		--	message = string.sub(message,26)
		--end
		DraconisErusRaidRecorder:Print(message)
	end
end

function DraconisErus_TableToString(tbl)
	--converts a simple table into a list string ex. { "item1", "item2", "item3" }
	--becomes "item1","item2","item3"
	local s = ""
	for _,p in ipairs(tbl) do  
		s = s .. "," .. p
	end
	return string.sub(s, 2)      -- remove first comma
end

function DraconisErus_FixName(player)
	local retVal = player
	local charpos = strfind(player,"-")
	if charpos ~= nil then
		retVal = strsub(player, 1, charpos-1)  --remove server from player name.  example: Feyde-Ashkandi
	end
	return retVal
end

function DraconisErus_Class_Colorize(class,text)
	return "|c"..dedkp_class_info[class].h..text.."|r"
end

function DraconisErus_SaveWindowPosition(windowName, widget)
	local point, relativeTo, relativePoint, xOfs, yOfs = widget:GetPoint()
	DEDKPWindows[windowName] = { point, nil, relativePoint, xOfs, yOfs }
end

function DraconisErus_SetWindowPosition(windowName, widget)
	if DEDKPWindows[windowName] ~= nil then
		if table.getn(DEDKPWindows[windowName]) > 0 then
			local point = DEDKPWindows[windowName]
			widget:ClearAllPoints()
			widget:SetPoint(point[1],nil,point[3],point[4],point[5])
		end
	end
end

function DraconisErus_Button_OnEnter(self)
	if self.tooltip ~= nil then
		GameTooltip:SetOwner(self,"ANCHOR_RIGHT")
		GameTooltip:SetText(self.tooltip,nil,nil,nil,nil,true)
		GameTooltip:Show()
	end
	if self.itemlink ~= nil then
		GameTooltip:SetOwner(self,"ANCHOR_RIGHT")
		GameTooltip:SetHyperlink(self.itemlink)
		GameTooltip:Show()
	end
end

function DraconisErus_Button_OnLeave(self)
	GameTootip:Hide()
end

function DraconisErus_PlayerAuth(isOfficer, inRaid, raidStarted)
	if isOfficer == 1 then
		if not DraconisErus_Guild_IsOfficer(DERR_PLAYER) then return false end	--am I an officer?
	end
	if inRaid == 1 then
		if not IsInRaid() then return false end	--am I in a raid?
	end
	if raidStarted == 1 then
		if not DEDKPSettings["RaidStarted"] then return false end	--has the raid been started?
	end
	return true
end

function DraconisErus_SenderAuth(sender, inGuild, isOfficer, inRaid)
	if isOfficer == 1 then
		if not DraconisErus_Guild_IsOfficer(sender) then return false end	--is sender an officer of my guild?
	end
	if inGuild == 1 then
		if not DraconisErus_Guild_HasPlayer(sender) then return false end	--is sender a member of my guild?
	end
	if inRaid == 1 then
		if not IsInRaid() then return false end
		if not DraconisErus_Raid_HasPlayer(sender) then return false end	--is sender in my current raid?
	end
	return true
end

function DraconisErus_GetLoot(lootmsg)
	local player, itemLink, amount = Deformat(lootmsg, LOOT_ITEM_MULTIPLE)
	if not itemLink then player, itemLink, amount = Deformat(lootmsg, LOOT_ITEM_PUSHED_MULTIPLE) end
	if not itemLink then itemLink, amount = Deformat(lootmsg, LOOT_ITEM_PUSHED_SELF_MULTIPLE) end
	if not itemLink then itemLink, amount = Deformat(lootmsg, LOOT_ITEM_SELF_MULTIPLE) end

	if not itemLink then player, itemLink = Deformat(lootmsg, LOOT_ITEM) end
	if not itemLink then player, itemLink = Deformat(lootmsg, LOOT_ITEM_PUSHED) end
	if not itemLink then itemLink = Deformat(lootmsg, LOOT_ITEM_PUSHED_SELF) end
	if not itemLink then itemLink = Deformat(lootmsg, LOOT_ITEM_SELF) end

	if itemLink then
		if not amount then
			amount = 1
		end
		if not player then
			player = DERR_PLAYER
		end
		return player, itemLink, amount
	end
end

function DraconisErus_PlaySound(soundname)
	local soundfolder = "Interface\\AddOns\\DraconisErusRaidRecorder\\Sounds\\";
	PlaySoundFile(soundfolder..soundname..".ogg", "Master");
end

function DraconisErus_PlayNewVersion()
	if DERR_GENDER == 2 then
		DraconisErus_PlaySound("newversionmale")
	else
		DraconisErus_PlaySound("newversionfemale")
	end
end

function DraconisErus_Tooltip(tooltip)
	local _, item_link = tooltip:GetItem()
	if not item_link then return; end

	itemId = tonumber(select(3, strfind(item_link, "item:(%d+)")))

	if itemId == "" or itemId == nil or itemId == " " then return; end

	local item = DEDKP_LOOT_PRIORITY[itemId]

	if not item then return; end

	local tt
	if item.first ~= "" then
		tt = "First: |cFF008000"..item.first.."|r";
		tooltip:AddLine(tt);
	else
		tt = "First: |cFF008000None|r";
		tooltip:AddLine(tt);
	end
	if item.second ~= "" then
		tt = "Second: |cFFFFFF00"..item.second.."|r";
		tooltip:AddLine(tt);
	end
	if item.third ~= "" then
		tt = "Third: |cFFFFA500"..item.third.."|r";
		tooltip:AddLine(tt);
	end

	if item.dkp ~= "" then
		tt = "Min Bid: |cFFFFA500"..item.dkp.."|r";
		tooltip:AddLine(tt);
	else
		tt = "Min Bid: |cFFFFA5000|r";
		tooltip:AddLine(tt);
	end

end
